import React, { Component } from 'react';
import { Toast, Button } from 'antd-mobile';
import './style.scss';
import eqIcon from '../../images/Equipment/equip_number_icon@2x.png';
import testIcon from '../../images/Equipment/test_water_icon@2x.png';
import scanImg from '../../images/Equipment/scan.png';
import WxWrap from '../../HOC/wx';
import { unbindKeyboard, getUnbindKeyboardResult } from '../../api';
import rateIcon from '../../images/Equipment/rate_active_icon@2x.png';

let DeviceCode = '';
class EquipmentTest extends Component {
  state = {
    deviceCode: DeviceCode,
    getTime: 0,
    timer: null,
  };

  componentWillMount() {
    const { setTitle } = this.props;
    setTitle('功能页');
  }
  changeHandle = e => {
    this.setState({
      deviceCode: e.target.value.trim(),
    });
    DeviceCode = e.target.value.trim();
  };
  validateDeviceCode = () => {
    const { deviceCode } = this.state;
    return deviceCode ? true : false;
  };
  goPage = path => {
    if (this.validateDeviceCode()) {
      const { history } = this.props;
      const { deviceCode } = this.state;
      history.push(`/Equipment/${deviceCode}` + path);
    } else {
      Toast.fail('请输入设备编号');
    }
  };
  scanEquipment = () => {
    const { wxDone, wxConfigHandle } = this.props;
    console.log('wxDone', wxDone);

    if (wxDone) {
      this.scanHandle();
    } else {
      wxConfigHandle()
        .then(() => {
          console.log('in res');
          this.scanHandle();
        })
        .catch(() => {
          console.log('in error');
          Toast.fail('启用微信失败！');
        });
    }
  };
  scanHandle = () => {
    const { wxConfigHandle } = this.props;
    const wx = window.wx;
    wx.scanQRCode({
      needResult: 1, // 默认为0，扫描结果由微信处理，1则直接返回扫描结果，
      scanType: ['qrCode', 'barCode'], // 可以指定扫二维码还是一维码，默认二者都有
      success: res => {
        const result = res.resultStr; // 当needResult 为 1 时，扫码返回的结果
        this.setState({
          deviceCode: result,
        });
      },
      fail: err => {
        console.log(err);
        Toast.info(err.errMsg || '调用扫一扫失败！');
        wxConfigHandle();
      },
    });
  };

  clickHandle = () => {
    const { deviceCode } = this.state;
    if (!deviceCode) {
      Toast.fail('请输入设备编号或扫设备二维码');
      return;
    }
    Toast.loading('', 99);
    return unbindKeyboard({
      deviceCode: deviceCode,
    })
      .then(() => {
        this.loopUntilGetResult();
      })
      .catch(err => {
        Toast.fail(err.msg || '请求解除键盘失败');
      });
  };

  loopUntilGetResult = () => {
    let timer = setInterval(() => {
      this.getResult();
    }, 1000);
    this.setState({ timer });
  };

  getResult = () => {
    const { deviceCode } = this.state;
    const { getTime } = this.state;
    if (getTime === 10) {
      return;
    }
    this.setState(({ getTime }) => ({
      getTime: getTime + 1,
    }));
    return getUnbindKeyboardResult({
      deviceCode: deviceCode,
    })
      .then(() => {
        const { timer } = this.state;
        clearInterval(timer);
        Toast.success('解除键盘设备');
        this.setState({
          timer: null,
          getTime: 0,
        });
      })
      .catch(err => {
        const { getTime, timer } = this.state;
        if (getTime === 10) {
          clearInterval(timer);
          Toast.fail(err.msg || '解除键盘设备失败');
          this.setState({
            timer: null,
            getTime: 0,
          });
        }
        console.error(err);
      });
  };
  render() {
    const { deviceCode } = this.state;
    return (
      <div className='appContent Equipment'>
        <div className='inputBox'>
          <div className='listItem'>
            <i className='inputIcon'>
              <img src={eqIcon} alt='' />
            </i>
            <span className='ellipsis inputText'>
              设备编号：
              <input
                className='br8 listInput'
                onChange={this.changeHandle}
                type='text'
                placeholder='请输入设备编号'
                maxLength='8'
                value={deviceCode}
              />
            </span>
          </div>
          <Button type='primary' className='scan' onClick={this.scanEquipment}>
            <div className='scanicon'>
              <img src={scanImg} alt='' />
            </div>
          </Button>
        </div>

        <div className='br8 btnBox testBtnBox'>
          <div className='linkItem' onClick={() => this.goPage('/TestWater')}>
            <i className='linkIcon'>
              <img src={testIcon} alt='' />
            </i>
            <span>测试吹风</span>
          </div>
        </div>
        <div className='linkItem' onClick={this.clickHandle}>
          <i className='linkIcon'>
            <img src={rateIcon} alt='' />
          </i>
          <span>解绑键盘设备</span>
        </div>
      </div>
    );
  }
}

export default props => (
  <WxWrap render={state => <EquipmentTest {...props} {...state} />} />
);
