import React from 'react';
import PropTypes from 'prop-types';
import { Link } from 'react-router-dom';
import './style.scss';
import eqIcon from '../../images/Equipment/equip_number_icon@2x.png';
import bindIcon from '../../images/Equipment/link_position_icon@2x.png';
import testIcon from '../../images/Equipment/test_water_icon@2x.png';
import rateIcon from '../../images/Equipment/rate_active_icon@2x.png';
import UserInfoContext from '../../context/userinfo-context';
import { unbindKeyboard, getUnbindKeyboardResult } from '../../api';
import { Toast } from 'antd-mobile';

export class Index extends React.Component {
  static propTypes = {
    name: PropTypes.string,
  };

  constructor(props) {
    super(props);
    this.state = {
      getTime: 0,
      timer: null,
    };
  }

  componentWillMount() {
    const { setTitle } = this.props;
    setTitle('功能页');
  }
  componentWillUnmount() {
    const { timer } = this.state;
    if (timer) {
      clearInterval(timer);
    }
  }

  clickHandle = () => {
    Toast.loading('', 99);
    const { deviceCode } = this.props.match.params;
    return unbindKeyboard({
      deviceCode: deviceCode,
    })
      .then(() => {
        this.loopUntilGetResult();
      })
      .catch(err => {
        Toast.fail(err.msg || '请求解除键盘失败');
      });
  };

  loopUntilGetResult = () => {
    let timer = setInterval(() => {
      this.getResult();
    }, 1000);
    this.setState({ timer });
  };

  getResult = () => {
    const { deviceCode } = this.props.match.params;
    const { getTime } = this.state;
    if (getTime === 10) {
      return;
    }
    this.setState(({ getTime }) => ({
      getTime: getTime + 1,
    }));
    return getUnbindKeyboardResult({
      deviceCode: deviceCode,
    })
      .then(() => {
        const { timer } = this.state;
        clearInterval(timer);
        Toast.success('解除键盘设备');
        this.setState({
          timer: null,
          getTime: 0,
        });
      })
      .catch(err => {
        const { getTime, timer } = this.state;
        if (getTime === 10) {
          clearInterval(timer);
          Toast.fail(err.msg || '解除键盘设备失败');
          this.setState({
            timer: null,
            getTime: 0,
          });
        }
        console.error(err);
      });
  };

  render() {
    const { deviceCode } = this.props.match.params;

    return (
      <div className='appContent Equipment'>
        <div className='inputBox'>
          <i className='inputIcon'>
            <img src={eqIcon} alt='' />
          </i>
          <span className='ellipsis inputText'>
            设备编号：
            {deviceCode}
          </span>
        </div>
        <div className='br8 btnBox'>
          {/* <div className='boxB boxBs' />
          <div className='boxBv' /> */}
          <Link
            className='linkItem'
            to={'/Equipment/' + deviceCode + '/SelectEquipment'}>
            <i className='linkIcon'>
              <img src={bindIcon} alt='' />
            </i>
            <span>绑定解绑位置</span>
          </Link>
          <Link
            className='linkItem'
            to={'/Equipment/' + deviceCode + '/TestWater'}>
            <i className='linkIcon'>
              <img src={testIcon} alt='' />
            </i>
            <span>测试吹风</span>
          </Link>
          <Link
            className='linkItem'
            to={'/Equipment/' + deviceCode + '/RateActivity'}>
            <i className='linkIcon'>
              <img src={rateIcon} alt='' />
            </i>
            <span>费率激活</span>
          </Link>
          <div className='linkItem' onClick={this.clickHandle}>
            <i className='linkIcon'>
              <img src={rateIcon} alt='' />
            </i>
            <span>解绑键盘设备</span>
          </div>
        </div>
      </div>
    );
  }
}

export default props => (
  <UserInfoContext.Consumer>
    {({ updateUserInfo, userinfo }) => (
      <Index {...props} updateUserInfo={updateUserInfo} userinfo={userinfo} />
    )}
  </UserInfoContext.Consumer>
);
